@@ -417,7 +417,7 @@ bool URLMethods::urlDecode(void)
 				hex[1] = *(++sp);
 				hex[2] = 0;
 				++sp;
-				c = strtol(hex, NULL, 16);
+				c = (char)strtol(hex, NULL, 16);
 				*(dp++) = c;								
 			}	
 			else
