@@ -355,6 +355,9 @@ bool ScriptCommand::useKeywords(Line *line, const char *list)
 bool ScriptCommand::hasKeywords(Line *line)
 {
 	unsigned idx = 0;
+
+	if(!stricmp(line->cmd, "_keydata_"))
+		return true;
 	
 	while(idx < line->argc)
 		if(*line->args[idx++] == '=')
@@ -363,6 +366,30 @@ bool ScriptCommand::hasKeywords(Line *line)
 	return false;
 }
 
+const char *ScriptCommand::findKeyword(ScriptImage *img, Line *line, const char *keyword)
+{
+	unsigned idx = 0;
+	const char *cp;
+	char namebuf[128];
+
+	while(idx < line->argc)
+	{
+		cp = line->args[idx++];
+		if(*cp == '=')
+		{
+			if(!stricmp(++cp, keyword))
+				return line->args[idx];
+			++idx;
+		}
+	}
+	if(img)
+	{
+		snprintf(namebuf, sizeof(namebuf), "%s.%s", img->getCurrent()->name, keyword);
+		return img->getLast(namebuf);
+	}
+	return NULL;
+}	
+
 const char *ScriptCommand::findKeyword(Line *line, const char *keyword)
 {
 	unsigned idx = 0;
