@@ -883,6 +883,7 @@ keytoken:
 				line->args = (const char **)alloc(sizeof(char *));
 				line->argc = 0;
 				line->args[0] = NULL;
+				line->scr.method = handler;
 
 				err = cmds->check(command, line, this);
 				if(err)
@@ -891,7 +892,13 @@ keytoken:
 						slog.error("%s(%d): %s: %s", filename, lnum, command, err);
 				}
 				else
-				{
+				{		
+					// second copy in case compile-time registration
+					if(line->scr.method != handler)
+					{
+						line = (Line *)memcpy(alloc(sizeof(Line)), line, sizeof(Line));
+						line->scr.method = handler;
+					}
 					++count;
 					if(!script->first)
 						script->first = line;
