@@ -65,6 +65,7 @@
 #define	SCRIPT_EXEC_WRAPPER
 #define	SCRIPT_APPS_WRAPPER
 #define	SCRIPT_RIPPLE_LEVEL 2
+#define	SCRIPT_RIPPLE_KEYDATA
 #define	SCRIPT_BINDER_SELECT
 #define	SCRIPT_SERVER_PREFIX
 #define	SCRIPT_DEFINE_TOKENS
@@ -525,6 +526,16 @@ public:
 	 */
 	static const char *findKeyword(Line *line, const char *keyword);
 
+    /**
+     * Test for a specific keyword or keydata filler.
+     *
+     * @return content of keyword that is found.
+	 * @param script image for keydata.
+     * @param line pointer to record to examine in check routine.
+     * @param keyword to search for.
+     */
+    static const char *findKeyword(ScriptImage *img, Line *line, const char *keyword);
+
 	/**
 	 * Server level logging interface override.
 	 *
